@@ -13,17 +13,12 @@
 #' displayed (position, colour, size, etc.).  You can learn the basics
 #' at \href{http://www.w3schools.com/css/}{W3Schools}.
 #'
-#' @param ... The following parameters are available:
-#' \tabular{ll}{
-#'   \strong{\code{id}}        \tab The id of the element/Shiny tag \cr
-#'   \strong{\code{class}}     \tab The CSS class to add/remove \cr
-#'   \strong{\code{condition}} \tab An optional argument to \code{toggleClass},
-#'                                  see 'Details' below. \cr
-#'   \strong{\code{selector}}   \tab JQuery selector of the elements to target.
-#'                                   Ignored if the \code{id} argument is given.
-#'                                   For example, to add a certain class to all
-#'                                   inputs with class x, use \code{selector = "input.x"}\cr
-#' }
+#' @param id The id of the element/Shiny tag
+#' @param class The CSS class to add/remove
+#' @param condition An optional argument to \code{toggleClass}, see 'Details' below.
+#' @param selector JQuery selector of the elements to target. Ignored if the \code{id}
+#' argument is given. For example, to add a certain class to all inputs with class x,
+#' use \code{selector = "input.x"}
 #' @seealso \code{\link[shinyjs]{useShinyjs}},
 #' \code{\link[shinyjs]{runExample}},
 #' \code{\link[shinyjs]{inlineCSS}},
@@ -31,16 +26,18 @@
 #' in the app's ui.
 #' @examples
 #' if (interactive()) {
-#'   shiny::shinyApp(
-#'     ui = shiny::fluidPage(
+#'   library(shiny)
+#'
+#'   shinyApp(
+#'     ui = fluidPage(
 #'       useShinyjs(),  # Set up shinyjs
 #'       # Add a CSS class for red text colour
 #'       inlineCSS(list(.red = "background: red")),
-#'       shiny::actionButton("btn", "Click me"),
-#'       shiny::p(id = "element", "Watch what happens to me")
+#'       actionButton("btn", "Click me"),
+#'       p(id = "element", "Watch what happens to me")
 #'     ),
 #'     server = function(input, output) {
-#'       shiny::observeEvent(input$btn, {
+#'       observeEvent(input$btn, {
 #'         # Change the following line for more examples
 #'         toggleClass("element", "red")
 #'       })
@@ -58,15 +55,15 @@
 #' ## toggleClass can be given an optional `condition` argument, which
 #' ## determines if to add or remove the class
 #' if (interactive()) {
-#'   shiny::shinyApp(
-#'     ui = shiny::fluidPage(
+#'   shinyApp(
+#'     ui = fluidPage(
 #'       useShinyjs(),
 #'       inlineCSS(list(.red = "background: red")),
-#'       shiny::checkboxInput("checkbox", "Make it red"),
-#'       shiny::p(id = "element", "Watch what happens to me")
+#'       checkboxInput("checkbox", "Make it red"),
+#'       p(id = "element", "Watch what happens to me")
 #'     ),
 #'     server = function(input, output) {
-#'       shiny::observe({
+#'       observe({
 #'         toggleClass(id = "element", class = "red",
 #'                     condition = input$checkbox)
 #'       })
@@ -78,10 +75,22 @@ NULL
 
 #' @export
 #' @rdname classFuncs
-addClass <- jsFunc
+addClass <- function(id, class, selector) {
+  fxn <- "addClass"
+  params <- as.list(match.call())[-1]
+  jsFuncHelper(fxn, params)
+}
 #' @export
 #' @rdname classFuncs
-removeClass <- jsFunc
+removeClass <- function(id, class, selector) {
+  fxn <- "removeClass"
+  params <- as.list(match.call())[-1]
+  jsFuncHelper(fxn, params)
+}
 #' @export
 #' @rdname classFuncs
-toggleClass <- jsFunc
+toggleClass <- function(id, class, condition, selector) {
+  fxn <- "toggleClass"
+  params <- as.list(match.call())[-1]
+  jsFuncHelper(fxn, params)
+}
